from setuptools import setup

setup(
    name = 'find_primes',
    version = '1.1.0',
    author = 'JamesJ',
    author_email = 'GGJamesQQ@yeah.net',
    description = 'A module for finding primes.',
    classifiers = [
        'Programming Language :: Python :: 3 :: Only',
        'License :: OSI Approved :: MIT License',
        'Development Status :: 4 - Beta'
    ],
    packages = ['find_primes'],
    python_requires = '>=3.6'
)